@@ -1,11 +1,12 @@
 import abc
 from copy import copy
 from functools import singledispatch
-from typing import Callable, List
+from typing import Callable, List, Tuple
 
 from aesara.graph.basic import Apply, Variable
 from aesara.graph.op import Op
 from aesara.graph.utils import MetaType
+from aesara.tensor.elemwise import Elemwise
 from aesara.tensor.random.op import RandomVariable
 
 
@@ -116,3 +117,20 @@ def assign_custom_measurable_outputs(
     _get_measurable_outputs.register(new_op_type)(measurable_outputs_fn)
 
     return new_node
+
+
+class MeasurableElemwise(Elemwise):
+    """Base class for Measurable Elemwise variables"""
+
+    valid_scalar_types: Tuple[MetaType, ...] = ()
+
+    def __init__(self, scalar_op, *args, **kwargs):
+        if not isinstance(scalar_op, self.valid_scalar_types):
+            raise TypeError(
+                f"scalar_op {scalar_op} is not valid for class {self.__class__}. "
+                f"Acceptable types are {self.valid_scalar_types}"
+            )
+        super().__init__(scalar_op, *args, **kwargs)
+
+
+MeasurableVariable.register(MeasurableElemwise)
